BackendKind

Enum BackendKind 

#[non_exhaustive]
pub enum BackendKind { IniNom, IniRE, }
The configuration backend to use for parsing the input data.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


IniNom

Parse INI-style files and their sections using the Nom-based backend.



IniRE

Parse INI-style files and their sections using the legacy regex-based backend.

Implementations

Source

impl BackendKind

pub const INI_NOM: &'static str = "ini-nom"

The name of the Nom-based INI-style file backend.

pub const INI_RE: &'static str = "ini-regex"

The name of the legacy regex-based INI-style file backend.

pub const fn get_preferred_ini_backend() -> Self

Return the most suitable backend type for INI-style files.

pub const fn get_preferred_ini_backend_name() -> &'static str

Return the name of the most suitable backend type for INI-style files.